@@ -1,7 +1,7 @@
 class Clojure < Formula
   desc "The Clojure Programming Language"
   homepage "https://clojure.org"
-  url "https://download.clojure.org/install/clojure-tools-1.9.0.315.tar.gz"
+  url "https://download.clojure.org/install/clojure-tools-1.9.0.348.tar.gz"
   sha256 "SHA"
 
   bottle :unneeded
@@ -11,6 +11,8 @@ class Clojure < Formula
 
   def install
     system "./install.sh", prefix
+    man1.install "clojure.1"
+    man1.install "clj.1"
   end
 
   test do
